import { CoreAssistantMessage, CoreMessage, CoreToolMessage, CoreUserMessage, UserContent } from 'ai';
import { ZodSchema } from 'zod';
import { Integration } from '../integration';
import { LLM } from '../llm';
import { ModelConfig, StructuredOutput } from '../llm/types';
import { Logger } from '../logger';
import { MastraMemory } from '../memory';
import { Run } from '../run/types';
import { Telemetry } from '../telemetry';
import { AllTools, CoreTool, ToolApi } from '../tools/types';
export declare class Agent<TTools, TIntegrations extends Integration[] | undefined = undefined, TKeys extends keyof AllTools<TTools, TIntegrations> = keyof AllTools<TTools, TIntegrations>> {
    #private;
    name: string;
    private memory?;
    readonly llm: LLM<TTools, TIntegrations, TKeys>;
    readonly instructions: string;
    readonly model: ModelConfig;
    readonly enabledTools: Partial<Record<TKeys, boolean>>;
    constructor(config: {
        name: string;
        instructions: string;
        model: ModelConfig;
        enabledTools?: Partial<Record<TKeys, boolean>>;
    });
    /**
     * Set the concrete tools for the agent
     * @param tools
     */
    __setTools(tools: Record<TKeys, ToolApi>): void;
    /**
     * Set the logger for the agent
     * @param logger
     */
    __setLogger(logger: Logger): void;
    __setMemory(memory: MastraMemory): void;
    /**
     * Set the telemetry for the agent
     * @param telemetry
     */
    __setTelemetry(telemetry: Telemetry): void;
    generateTitleFromUserMessage({ message }: {
        message: CoreUserMessage;
    }): Promise<string>;
    getMostRecentUserMessage(messages: Array<CoreMessage>): CoreUserMessage | undefined;
    genTitle(userMessage: CoreUserMessage | undefined): Promise<string>;
    saveMemory({ threadId, resourceid, userMessages, }: {
        resourceid: string;
        threadId?: string;
        userMessages: CoreMessage[];
        time?: Date;
        keyword?: string;
    }): Promise<{
        threadId: string;
        messages: CoreMessage[];
    }>;
    saveResponse({ result, threadId }: {
        result: Record<string, any>;
        threadId: string;
    }): Promise<void>;
    sanitizeResponseMessages(messages: Array<CoreToolMessage | CoreAssistantMessage>): Array<CoreToolMessage | CoreAssistantMessage>;
    convertTools({ enabledTools, threadId, runId, }: {
        enabledTools?: Partial<Record<TKeys, boolean>>;
        threadId: string;
        runId?: string;
    }): Record<TKeys, CoreTool>;
    preExecute({ resourceid, runId, threadId, messages, }: {
        runId?: string;
        threadId?: string;
        messages: CoreMessage[];
        resourceid: string;
    }): Promise<{
        coreMessages: CoreMessage[];
        threadIdToUse: string;
    }>;
    __primitive({ messages, context, threadId, resourceid, runId, }: {
        resourceid?: string;
        threadId?: string;
        context?: CoreMessage[];
        runId?: string;
        messages: UserContent[];
    }): {
        before: () => Promise<{
            messageObjects: CoreMessage[];
            convertedTools: Record<TKeys, CoreTool> | undefined;
            threadId: string;
        }>;
        after: ({ result, threadId }: {
            result: Record<string, any>;
            threadId: string;
        }) => Promise<void>;
    };
    text({ messages, context, onStepFinish, maxSteps, threadId: threadIdInFn, resourceid, runId, }: {
        resourceid?: string;
        threadId?: string;
        context?: CoreMessage[];
        messages: UserContent[];
        onStepFinish?: (step: string) => void;
        maxSteps?: number;
    } & Run): Promise<import("ai").GenerateTextResult<{}, never>>;
    textObject({ messages, context, structuredOutput, onStepFinish, maxSteps, threadId: threadIdInFn, resourceid, runId, }: {
        context?: CoreMessage[];
        resourceid?: string;
        threadId?: string;
        messages: UserContent[];
        structuredOutput: StructuredOutput | ZodSchema;
        onStepFinish?: (step: string) => void;
        maxSteps?: number;
    } & Run): Promise<import("ai").GenerateObjectResult<any>>;
    stream({ messages, context, onStepFinish, onFinish, maxSteps, threadId: threadIdInFn, resourceid, runId, }: {
        resourceid?: string;
        threadId?: string;
        messages: UserContent[];
        context?: CoreMessage[];
        onStepFinish?: (step: string) => void;
        onFinish?: (result: string) => Promise<void> | void;
        maxSteps?: number;
    } & Run): Promise<import("ai").StreamTextResult<{}>>;
    streamObject({ messages, context, structuredOutput, onStepFinish, onFinish, maxSteps, threadId: threadIdInFn, resourceid, runId, }: {
        resourceid?: string;
        threadId?: string;
        messages: UserContent[];
        context?: CoreMessage[];
        structuredOutput: StructuredOutput | ZodSchema;
        onStepFinish?: (step: string) => void;
        onFinish?: (result: string) => Promise<void> | void;
        maxSteps?: number;
    } & Run): Promise<import("ai").StreamObjectResult<any, any, never>>;
}
