import { ZodSchema } from 'zod';
import { Agent } from '../agent';
import { MastraEngine } from '../engine';
import { Integration } from '../integration';
import { LLM } from '../llm';
import { ModelConfig } from '../llm/types';
import { StripUndefined } from '../mastra/types';
import { Run } from '../run/types';
export type CoreTool = {
    description: string;
    parameters: ZodSchema;
    execute: (params: any) => Promise<any>;
};
interface ToolIntegrations<I extends Integration[]> {
    get: <N extends I[number]['name']>(name: N) => Extract<I[number], {
        name: N;
    }>;
}
export type ToolApi<IN extends Record<string, unknown> = Record<string, unknown>, OUT extends Record<string, unknown> = Record<string, unknown>> = {
    schema: ZodSchema<IN>;
    label: string;
    description: string;
    documentation?: string;
    outputSchema?: ZodSchema<OUT>;
    executor: (params: IntegrationApiExcutorParams<IN>) => Promise<OUT>;
    enableCache?: boolean;
};
export type IntegrationTools<T extends Integration> = T['tools'];
type UnionToIntersection<U> = (U extends any ? (k: U) => void : never) extends (k: infer I) => void ? I : never;
export type MergeIntegrationTools<T extends Integration[]> = UnionToIntersection<IntegrationTools<T[number]>>;
export type AllTools<TTools, TIntegrations extends Integration[] | undefined = undefined> = (TTools extends Record<string, ToolApi<any, any>> ? TTools : {}) & (TIntegrations extends Integration[] ? MergeIntegrationTools<StripUndefined<TIntegrations>> : {});
export interface IntegrationApiExcutorParams<T extends Record<string, unknown>> {
    data: T;
    runId?: Run['runId'];
    integrationsRegistry: <I extends Integration[]>() => ToolIntegrations<I>;
    llm: (model: ModelConfig) => LLM<AllTools<any, Integration[]>, Integration[], any>;
    engine?: MastraEngine | undefined;
    agents: Map<string, Agent<any>>;
}
export {};
